@@ -1,11 +1,8 @@
 from inspector_commons.bridge.base import Bridge, traceback
 from inspector_commons.bridge.mixin import DatabaseMixin
-from inspector_commons.windows_driver import (
-    MatchedWindowsLocators,
-    OpenWindows,
-    WindowsDriver,
-    WindowsLocator,
-)
+from inspector_commons.windows_driver import (MatchedWindowsLocators,
+                                              OpenWindows, WindowsDriver,
+                                              WindowsLocator)
 
 
 class WindowsBridge(DatabaseMixin, Bridge):
